@@ -1,10 +1,8 @@
 import pytest
 
-from qqmusic_api.singer import (
-    TabType,
-)
+from qqmusic_api.singer import TabType
 
-pytestmark = pytest.mark.asyncio(scope="package")
+pytestmark = pytest.mark.asyncio(loop_scope="session")
 
 
 async def test_get_info(singer):
